@@ -1,4 +1,4 @@
-# $Id: Mapping.pm 68 2007-10-06 10:14:44Z cfaerber $
+# $Id: Mapping.pm 83 2008-09-20 14:51:23Z cfaerber $
 
 package Unicode::Stringprep::Mapping;
 
@@ -2281,10 +2281,14 @@ This module exports nothing.
 
 =head1 AUTHOR
 
-Claus Färber
+Claus Färber E<lt>CFAERBER@cpan.orgE<gt>
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 LICENSE
+
+Copyright © 2007-2008 Claus Färber. All rights reserved.
+
+This library is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
